#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from persistent import Persistent
from zope.container.contained import Contained
from zope.interface import Interface, implementer
from zope.schema.fieldproperty import FieldProperty

from pyams_content.shared.view.portlet.interfaces import IViewItemsPortletSettings
from pyams_default_theme.shared.view.portlet.interfaces import IViewItemsPortletVerticalRendererSettings
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.factory import factory_config

from pyams_default_theme import _


@factory_config(provided=IViewItemsPortletVerticalRendererSettings)
@implementer(IViewItemsPortletVerticalRendererSettings)
class ViewItemsPortletVerticalRendererSettings(Persistent, Contained):
    """View items portlet renderer settings"""

    display_illustrations = FieldProperty(IViewItemsPortletVerticalRendererSettings['display_illustrations'])
    paginate = FieldProperty(IViewItemsPortletVerticalRendererSettings['paginate'])
    page_size = FieldProperty(IViewItemsPortletVerticalRendererSettings['page_size'])


@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IViewItemsPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/view-items-list.pt', layer=IPyAMSLayer)
class ViewItemsPortletVerticalRenderer(PortletRenderer):
    """View items portlet renderer"""

    label = _("Simple vertical view")
    weight = 0

    settings_interface = IViewItemsPortletVerticalRendererSettings
